LOCALES = {
	("bg-BG", "Bulgarian"),
	("cs-CZ", "Czech"),
	("da-DK", "Danish"),
	("de-DE", "German"),
	("el-GR", "Greek"),
	("en-US", "English"),
	("es-ES", "Spanish"),
	("et-EE", "Estonian"),
	("fi-FI", "Finnish"),
	("fr-FR", "French"),
	("hr-HR", "Croatian"),
	("hu-HU", "Hungarian"),
	("it-IT", "Italian"),
	("lt-LT", "Lithuanian"),
	("lv-LV", "Latvian"),
	("nl-NL", "Dutch"),
	("no-NO", "Norwegian"),
	("pl-PL", "Polish"),
	("pt-PT", "Portuguese"),
	("ro-RO", "Romanian"),
	("ru-RU", "Russian"),
	("sk-SK", "Slovak"),
	("sl-SI", "Slovenian"),
	("sv-SE", "Swedish"),
	("tr-TR", "Turkish"),
	("zh-CN", "Chinese"),
}